import request from '@/utils/request'
import { praseStrEmpty } from '@/utils/common'

// 查询用户列表
export function listUser(query) {
  return request({
    url: '/authority/system/user/list',
    method: 'get',
    params: query
  })
}
// selectUserIdsListDept 新查询用户接-口
export function selectUserIdsListDept(params) {
  return request({
    url: '/authority/system/user/listByDept',
    method: 'get',
    params
  })
}
// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/authority/system/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  return request({
    url: '/authority/system/user',
    method: 'post',
    data: data
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/authority/system/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/authority/system/user/' + userId,
    method: 'delete'
  })
}

// 导出用户
export function exportUser(query) {
  return request({
    url: '/authority/system/user/export',
    method: 'post',
    params: query
  })
}

// 用户密码重置
export function resetUserPwd(userId, password) {
  const data = {
    userId,
    password
  }
  return request({
    url: '/authority/system/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(userId, status) {
  const data = {
    userId,
    status
  }
  return request({
    url: '/authority/system/user/changeStatus',
    method: 'put',
    data: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/authority/system/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: '/authority/system/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(data) {
  return request({
    url: '/authority/system/user/profile/updatePwd',
    method: 'put',
    params: data
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/authority/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 下载用户导入模板
export function importTemplate() {
  return request({
    url: '/authority/system/user/importTemplate',
    method: 'get'
  })
}
// 控制用户能否登录
export function userLoginManage(data) {
  return request({
    url: '/authority/system/user/updateAllowLogin',
    method: 'post',
    data
  })
}
